==> xfce4-quicklauncher-plugin_1.9.1.orig.tar.gz: xfce4-quicklauncher-plugin-1.9.1/panel-plugin/avoid_deprecation.h <==
//This file is intented to avoid problems 
//with the fact that XfceFileChooser will be
//deprecated soon.
//Hope it works for everyone.
#include <gtk/gtk.h>

#if GTK_CHECK_VERSION(2,4,0)
	#define	FileChooser	GtkFileChooser
	#define	FileChooserAction	GtkFileChooserAction
	#define	file_chooser_dialog_new 	gtk_file_chooser_dialog_new 
	#define	file_chooser_new	gtk_file_chooser_dialog_new 
	#define	file_chooser_set_select_multiple	gtk_file_chooser_set_select_multiple
	#define	file_chooser_get_select_multiple	gtk_file_chooser_get_select_multiple
	#define	file_chooser_set_current_name	gtk_file_chooser_set_current_name
	#define	file_chooser_get_filename	gtk_file_chooser_get_filename  
	#define	file_chooser_set_filename	gtk_file_chooser_set_filename  
	#define	file_chooser_get_filenames	gtk_file_chooser_get_filenames
	#define	file_chooser_set_current_folder	gtk_file_chooser_set_current_folder
	#define	file_chooser_get_current_folder	gtk_file_chooser_get_current_folder
	#define	file_chooser_set_preview_widget	gtk_file_chooser_set_preview_widget
	#define	file_chooser_get_preview_widget	gtk_file_chooser_get_preview_widget
	#define	file_chooser_set_preview_callback(widget, func,data) \
	g_signal_connect(widget, "update-preview", G_CALLBACK(func), data);
	#define	file_chooser_set_preview_widget_active	gtk_file_chooser_set_preview_widget_active
	#define	file_chooser_get_preview_widget_active	gtk_file_chooser_get_preview_widget_active
	#define	file_chooser_set_use_preview_label	gtk_file_chooser_set_use_preview_label
	#define	file_chooser_set_extra_widget	gtk_file_chooser_set_extra_widget
	#define	file_chooser_get_extra_widget	gtk_file_chooser_get_extra_widget
	#define	file_chooser_add_filter	gtk_file_chooser_add_filter
	#define	file_chooser_remove_filter	gtk_file_chooser_remove_filter
	#define	file_chooser_set_filter	gtk_file_chooser_set_filter
	#define	file_chooser_set_local_only	gtk_file_chooser_set_local_only
	#define	file_chooser_get_local_only	gtk_file_chooser_get_local_only
	#define	file_chooser_add_shortcut_folder	gtk_file_chooser_add_shortcut_folder
	#define	file_chooser_remove_shortcut_folder	gtk_file_chooser_remove_shortcut_folder
	#define	FileFilter	GtkFileFilter
	#define	file_filter_new	gtk_file_filter_new 
	#define	file_filter_set_name	gtk_file_filter_set_name
	#define	file_filter_add_mime_type	gtk_file_filter_add_mime_type
	#define	file_filter_add_pattern	gtk_file_filter_add_pattern
	#define	FILE_CHOOSER	GTK_FILE_CHOOSER
	#define	FILE_FILTER	GTK_FILE_FILTER
	#define	FILE_CHOOSER_ACTION_OPEN	GTK_FILE_CHOOSER_ACTION_OPEN
	#define	FILE_CHOOSER_ACTION_SAVE	GTK_FILE_CHOOSER_ACTION_SAVE
	#define	FILE_CHOOSER_ACTION_SELECT_FOLDER	GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER
	#define	FILE_CHOOSER_ACTION_CREATE_FOLDER	GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER
#else
	#include <libxfcegui4.h>
	#if !LIBXFCEGUI4_CHECK_VERSION (4, 3, 0)
	#define	FileChooser	XfceFileChooser
	#define	FileChooserAction	XfceFileChooserAction
	#define	file_chooser_dialog_new 	xfce_file_chooser_dialog_new 
	#define	file_chooser_new	xfce_file_chooser_new
	#define	file_chooser_set_select_multiple	xfce_file_chooser_set_select_multiple
	#define	file_chooser_get_select_multiple	xfce_file_chooser_get_select_multiple
	#define	file_chooser_set_current_name	xfce_file_chooser_set_current_name
	#define	file_chooser_get_filename	xfce_file_chooser_get_filename  
	#define	file_chooser_set_filename	xfce_file_chooser_set_filename  
	#define	file_chooser_get_filenames	xfce_file_chooser_get_filenames
	#define	file_chooser_set_current_folder	xfce_file_chooser_set_current_folder
	#define	file_chooser_get_current_folder	xfce_file_chooser_get_current_folder
	#define	file_chooser_set_preview_widget	xfce_file_chooser_set_preview_widget
	#define	file_chooser_get_preview_widget	xfce_file_chooser_get_preview_widget
	#define	file_chooser_set_preview_callback	xfce_file_chooser_set_preview_callback
	#define	file_chooser_set_preview_widget_active	xfce_file_chooser_set_preview_widget_active
	#define	file_chooser_get_preview_widget_active	xfce_file_chooser_get_preview_widget_active
	#define	file_chooser_set_use_preview_label	xfce_file_chooser_set_use_preview_label
	#define	file_chooser_set_extra_widget	xfce_file_chooser_set_extra_widget
	#define	file_chooser_get_extra_widget	xfce_file_chooser_get_extra_widget
	#define	file_chooser_add_filter	xfce_file_chooser_add_filter
	#define	file_chooser_remove_filter	xfce_file_chooser_remove_filter
	#define	file_chooser_set_filter	xfce_file_chooser_set_filter
	#define	file_chooser_set_local_only	xfce_file_chooser_set_local_only
	#define	file_chooser_get_local_only	xfce_file_chooser_get_local_only
	#define	file_chooser_add_shortcut_folder	xfce_file_chooser_add_shortcut_folder
	#define	file_chooser_remove_shortcut_folder	xfce_file_chooser_remove_shortcut_folder
	#define	FileFilter	XfceFileFilter
	#define	file_filter_new	xfce_file_filter_new 
	#define	file_filter_set_name	xfce_file_filter_set_name
	#define	file_filter_add_mime_type	xfce_file_filter_add_mime_type
	#define	file_filter_add_pattern	xfce_file_filter_add_pattern
	#define	FILE_CHOOSER	XFCE_FILE_CHOOSER
	#define	FILE_FILTER	XFCE_FILE_FILTER
	#define	FILE_CHOOSER_ACTION_OPEN	XFCE_FILE_CHOOSER_ACTION_OPEN
	#define	FILE_CHOOSER_ACTION_SAVE	XFCE_FILE_CHOOSER_ACTION_SAVE
	#define	FILE_CHOOSER_ACTION_SELECT_FOLDER	XFCE_FILE_CHOOSER_ACTION_SELECT_FOLDER
	#define	FILE_CHOOSER_ACTION_CREATE_FOLDER	XFCE_FILE_CHOOSER_ACTION_CREATE_FOLDER
#else
	#error you must have gtk > 2.4.0 or libxfcegui4 < 4.3.0 in order to compile this!!!
	#endif
#endif

==> xfce4-quicklauncher-plugin_1.9.4.orig.tar.gz: xfce4-quicklauncher-plugin-1.9.4/panel-plugin/avoid_deprecation.h <==
/***************************************************************************
 *            avoid_deprecation.h
 *
 *  Last Update: 31/03/2007
 *  Copyright  2005 - 2007  bountykiller
 *  Email: masse_nicolas@yahoo.fr
 ****************************************************************************/
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Library General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

//This file is intented to avoid problems 
//with the fact that XfceFileChooser but also xfce_icon_theme_* will be deprecated soon.
//Hope it works for everyone.

#ifndef __QCK_LAUNCHER_AVOID_DEPRECATION__
#define __QCK_LAUNCHER_AVOID_DEPRECATION__

#include <gtk/gtk.h>

#if GTK_CHECK_VERSION(2,4,0)
	
	#define icon_theme_get_for_screen gtk_icon_theme_get_for_screen
	#define icon_theme_set_for_screen gtk_icon_theme_set_for_screen
	#define DEFAULT_ICON_THEME (gtk_icon_theme_get_default())
	
	#define	FileChooser	GtkFileChooser
	#define	FileChooserAction	GtkFileChooserAction
	#define	file_chooser_dialog_new 	gtk_file_chooser_dialog_new 
	#define	file_chooser_new	gtk_file_chooser_dialog_new 
	#define	file_chooser_set_select_multiple	gtk_file_chooser_set_select_multiple
	#define	file_chooser_get_select_multiple	gtk_file_chooser_get_select_multiple
	#define	file_chooser_set_current_name	gtk_file_chooser_set_current_name
	#define	file_chooser_get_filename	gtk_file_chooser_get_filename  
	#define	file_chooser_set_filename	gtk_file_chooser_set_filename  
	#define	file_chooser_get_filenames	gtk_file_chooser_get_filenames
	#define	file_chooser_set_current_folder	gtk_file_chooser_set_current_folder
	#define	file_chooser_get_current_folder	gtk_file_chooser_get_current_folder
	#define	file_chooser_set_preview_widget	gtk_file_chooser_set_preview_widget
	#define	file_chooser_get_preview_widget	gtk_file_chooser_get_preview_widget
	#define	file_chooser_set_preview_callback(widget, func,data) \
	g_signal_connect(widget, "update-preview", G_CALLBACK(func), data);
	#define	file_chooser_set_preview_widget_active	gtk_file_chooser_set_preview_widget_active
	#define	file_chooser_get_preview_widget_active	gtk_file_chooser_get_preview_widget_active
	#define	file_chooser_set_use_preview_label	gtk_file_chooser_set_use_preview_label
	#define	file_chooser_set_extra_widget	gtk_file_chooser_set_extra_widget
	#define	file_chooser_get_extra_widget	gtk_file_chooser_get_extra_widget
	#define	file_chooser_add_filter	gtk_file_chooser_add_filter
	#define	file_chooser_remove_filter	gtk_file_chooser_remove_filter
	#define	file_chooser_set_filter	gtk_file_chooser_set_filter
	#define	file_chooser_set_local_only	gtk_file_chooser_set_local_only
	#define	file_chooser_get_local_only	gtk_file_chooser_get_local_only
	#define	file_chooser_add_shortcut_folder	gtk_file_chooser_add_shortcut_folder
	#define	file_chooser_remove_shortcut_folder	gtk_file_chooser_remove_shortcut_folder
	#define	FileFilter	GtkFileFilter
	#define	file_filter_new	gtk_file_filter_new 
	#define	file_filter_set_name	gtk_file_filter_set_name
	#define	file_filter_add_mime_type	gtk_file_filter_add_mime_type
	#define	file_filter_add_pattern	gtk_file_filter_add_pattern
	#define	FILE_CHOOSER	GTK_FILE_CHOOSER
	#define	FILE_FILTER	GTK_FILE_FILTER
	#define	FILE_CHOOSER_ACTION_OPEN	GTK_FILE_CHOOSER_ACTION_OPEN
	#define	FILE_CHOOSER_ACTION_SAVE	GTK_FILE_CHOOSER_ACTION_SAVE
	#define	FILE_CHOOSER_ACTION_SELECT_FOLDER	GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER
	#define	FILE_CHOOSER_ACTION_CREATE_FOLDER	GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER
#else
	#include <libxfcegui4.h>
	#if !LIBXFCEGUI4_CHECK_VERSION (4, 3, 0)
	
	#define icon_theme_get_for_screen xfce_icon_theme_get_for_screen
	#define icon_theme_set_for_screen xfce_icon_theme_set_for_screen
	#define DEFAULT_ICON_THEME (xfce_icon_theme_get_for_screen(NULL))
	
	#define	FileChooser	XfceFileChooser
	#define	FileChooserAction	XfceFileChooserAction
	#define	file_chooser_dialog_new 	xfce_file_chooser_dialog_new 
	#define	file_chooser_new	xfce_file_chooser_new
	#define	file_chooser_set_select_multiple	xfce_file_chooser_set_select_multiple
	#define	file_chooser_get_select_multiple	xfce_file_chooser_get_select_multiple
	#define	file_chooser_set_current_name	xfce_file_chooser_set_current_name
	#define	file_chooser_get_filename	xfce_file_chooser_get_filename  
	#define	file_chooser_set_filename	xfce_file_chooser_set_filename  
	#define	file_chooser_get_filenames	xfce_file_chooser_get_filenames
	#define	file_chooser_set_current_folder	xfce_file_chooser_set_current_folder
	#define	file_chooser_get_current_folder	xfce_file_chooser_get_current_folder
	#define	file_chooser_set_preview_widget	xfce_file_chooser_set_preview_widget
	#define	file_chooser_get_preview_widget	xfce_file_chooser_get_preview_widget
	#define	file_chooser_set_preview_callback	xfce_file_chooser_set_preview_callback
	#define	file_chooser_set_preview_widget_active	xfce_file_chooser_set_preview_widget_active
	#define	file_chooser_get_preview_widget_active	xfce_file_chooser_get_preview_widget_active
	#define	file_chooser_set_use_preview_label	xfce_file_chooser_set_use_preview_label
	#define	file_chooser_set_extra_widget	xfce_file_chooser_set_extra_widget
	#define	file_chooser_get_extra_widget	xfce_file_chooser_get_extra_widget
	#define	file_chooser_add_filter	xfce_file_chooser_add_filter
	#define	file_chooser_remove_filter	xfce_file_chooser_remove_filter
	#define	file_chooser_set_filter	xfce_file_chooser_set_filter
	#define	file_chooser_set_local_only	xfce_file_chooser_set_local_only
	#define	file_chooser_get_local_only	xfce_file_chooser_get_local_only
	#define	file_chooser_add_shortcut_folder	xfce_file_chooser_add_shortcut_folder
	#define	file_chooser_remove_shortcut_folder	xfce_file_chooser_remove_shortcut_folder
	#define	FileFilter	XfceFileFilter
	#define	file_filter_new	xfce_file_filter_new 
	#define	file_filter_set_name	xfce_file_filter_set_name
	#define	file_filter_add_mime_type	xfce_file_filter_add_mime_type
	#define	file_filter_add_pattern	xfce_file_filter_add_pattern
	#define	FILE_CHOOSER	XFCE_FILE_CHOOSER
	#define	FILE_FILTER	XFCE_FILE_FILTER
	#define	FILE_CHOOSER_ACTION_OPEN	XFCE_FILE_CHOOSER_ACTION_OPEN
	#define	FILE_CHOOSER_ACTION_SAVE	XFCE_FILE_CHOOSER_ACTION_SAVE
	#define	FILE_CHOOSER_ACTION_SELECT_FOLDER	XFCE_FILE_CHOOSER_ACTION_SELECT_FOLDER
	#define	FILE_CHOOSER_ACTION_CREATE_FOLDER	XFCE_FILE_CHOOSER_ACTION_CREATE_FOLDER
#else
	#error you must have gtk > 2.4.0 or libxfcegui4 < 4.3.0 in order to compile this!!!
	#endif
#endif


#endif
